BuildResultModel class

Represents the result of a Flutter build execution.

Constructors

BuildResultModel({required bool isSuccess, required String target, required Duration buildDuration, String? originalArtifactPath, String? errorMessage})
const

Properties

buildDuration Duration
The time taken to execute the build.
final
errorMessage String?
Any error message generated during the build.
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
Whether the build was successful.
final
originalArtifactPath String?
The original path where Flutter placed the generated artifact. This will be null if the build failed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String
The target that was built (apk, aab, ipa).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited