originalArtifactPath property
The original path where Flutter placed the generated artifact. This will be null if the build failed.
Implementation
final String? originalArtifactPath;
The original path where Flutter placed the generated artifact. This will be null if the build failed.
final String? originalArtifactPath;