EnvironmentModel class

Represents the deployment or build environment (e.g., DEV, UAT, PROD).

Constructors

EnvironmentModel(String name)
Creates a new EnvironmentModel.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
The dynamic string representation of the environment.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override