FlutterSdkInfo class

Encapsulates information about the resolved Flutter SDK.

Constructors

FlutterSdkInfo({required String executablePath, required String version, required String dartVersion, required String engineVersion, required String frameworkRevision, required String channel, required bool isFvm, required bool isProjectFvm})
const

Properties

channel String
final
dartVersion String
final
engineVersion String
final
executablePath String
final
frameworkRevision String
final
hashCode int
The hash code for this object.
no setterinherited
isFvm bool
final
isProjectFvm bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited