initialize abstract method
Initialize the plugin with any necessary setup before execution.
The logger is provided so the plugin can output information uniformly.
Implementation
Future<void> initialize(ReleaseManagerLogger logger);
Initialize the plugin with any necessary setup before execution.
The logger is provided so the plugin can output information uniformly.
Future<void> initialize(ReleaseManagerLogger logger);