ArtifactLocatorService class

Service responsible for locating generated build artifacts.

Constructors

ArtifactLocatorService({List<ArtifactLocatorStrategy>? customStrategies})
Creates a new ArtifactLocatorService.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

locateArtifact(String type, {String? flavor, String? basePath}) Future<String>
Attempts to locate an artifact of the given type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited