MappingLocatorStrategy class
Properties
-
artifactType
→ String
-
The type of artifact this strategy locates (e.g., 'apk', 'mapping.txt').
no setteroverride
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
locate({String? flavor, String? basePath})
→ Future<String?>
-
Attempts to locate the artifact and returns its absolute path.
Returns null if the artifact cannot be found.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited