BuildCounterService class

Service responsible for managing daily incrementing release numbers per environment.

Constructors

BuildCounterService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getNextBuildNumber(String environment, {String? baseDir}) Future<String>
Generates the next build number for the given environment.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peekNextBuildNumber(String environment, {String? baseDir}) Future<String>
Peeks at what the next build number will be without modifying the state.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited