ChecksumService class

Service responsible for generating SHA256 checksums for artifacts.

Constructors

ChecksumService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateChecksum(String artifactPath) Future<String>
Generates a checksum file in the same directory as artifactPath.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited