EnvironmentDetectionStrategy class abstract

Abstract base class for environment detection strategies.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Returns a short name identifying the strategy (e.g., 'Manual Override').
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(ArgResults? argResults) Future<String?>
Attempts to detect the environment based on the strategy's rules.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited