EnvironmentService class

Service responsible for automatically determining the application's environment.

Constructors

EnvironmentService({required ReleaseManagerLogger logger, List<EnvironmentDetectionStrategy>? strategies})
Creates a new EnvironmentService.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectEnvironment(ArgResults? argResults) Future<EnvironmentModel>
Iterates through the detection strategies in order.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited