services/filename_template_service library

Classes

FilenameTemplateService
Service responsible for generating release filenames based on a template.
TemplateVariables
The variables that can be injected into a filename template.