FilenameTemplateService class

Service responsible for generating release filenames based on a template.

Constructors

FilenameTemplateService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateFilename(String template, TemplateVariables variables) String
Generates a validated filename based on the template and variables.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited