TemplateVariables class

The variables that can be injected into a filename template.

Constructors

TemplateVariables({String? project, String? version, String? flutterBuild, String? counter, String? env, String? platform, String? artifact, String? branch, String? commit})
const

Properties

artifact String?
final
branch String?
final
commit String?
final
counter String?
final
env String?
final
flutterBuild String?
final
hashCode int
The hash code for this object.
no setterinherited
platform String?
final
project String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited