FlutterSdkService class

Service responsible for locating and validating the Flutter SDK.

Constructors

FlutterSdkService({required ProcessService processService})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSdkInfo({String? basePath}) Future<FlutterSdkInfo>
Resolves the correct Flutter SDK and fetches its version info.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited