LoggerService class

Service responsible for daily persistent file logging.

Constructors

LoggerService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

error(String message, {dynamic error, StackTrace? stackTrace, String? baseDir}) Future<void>
Writes an error message to the daily log file.
info(String message, {String? baseDir}) Future<void>
Writes an info message to the daily log file.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
warning(String message, {String? baseDir}) Future<void>
Writes a warning message to the daily log file.

Operators

operator ==(Object other) bool
The equality operator.
inherited