MetadataService class

Service responsible for generating and validating release metadata JSON.

Constructors

MetadataService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateMetadataFile(ReleaseMetadataModel metadata) Future<String>
Generates the release.json file inside the target releaseDirectory.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited