ProjectService class

Service responsible for extracting general project information.

Constructors

ProjectService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProjectInfo({String pubspecPath = 'pubspec.yaml'}) Future<ProjectModel>
Reads the pubspec.yaml file and extracts the project name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited