VersionService class

Service responsible for automatically detecting project versioning details.

Constructors

VersionService({required ReleaseManagerLogger logger})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getVersionInfo({String pubspecPath = 'pubspec.yaml'}) Future<VersionModel>
Reads the pubspec.yaml file and extracts the version information.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited