ReleaseManagerLogger class

A global logger instance configured for the CLI.

This wraps the Logger from the mason_logger package and provides standard output coloring and formatting.

Constructors

ReleaseManagerLogger({Logger? logger})
Creates a ReleaseManagerLogger.

Properties

hashCode int
The hash code for this object.
no setterinherited
level ← Level
Sets the logging level.
no getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirm(String message, {bool defaultValue = false}) bool
Prompts the user for a boolean confirmation.
detail(String message) → void
Logs detailed diagnostic information (only shown if verbose mode is on).
err(String message) → void
Logs error messages.
info(String message) → void
Logs informational messages.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
success(String message) → void
Logs success messages.
toString() String
A string representation of this object.
inherited
warn(String message) → void
Logs warning messages.

Operators

operator ==(Object other) bool
The equality operator.
inherited