ReleaseManagerException class
Base exception class for all errors thrown by the Flutter Release Manager.
This ensures we can catch specific exceptions and handle them gracefully without exposing stack traces to the user unless they request it.
- Implemented types
Constructors
- ReleaseManagerException(String message, {Object? details})
-
Creates a new ReleaseManagerException with the given
messageand optionaldetails.const
Properties
- details → Object?
-
Optional technical details or underlying error that caused this exception.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A user-friendly message describing the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited