BuildStateModel class
Represents the state of the build counters.
Constructors
-
BuildStateModel({required String lastDate, required Map<
String, int> counters}) -
Creates a new BuildStateModel.
const
-
BuildStateModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
counters
→ Map<
String, int> -
Map of environment names to their current daily counter.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastDate → String
-
The last date a build was generated, format: yyyyMMdd
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited