ReleaseMetadataModel class

Represents the metadata associated with a generated release artifact.

Constructors

ReleaseMetadataModel({required String projectName, required String version, required String flutterBuildNumber, required String environment, required String counter, required String generatedFilename, required String artifactType, required int artifactSize, required String generatedTime, required String flutterVersion, required String dartVersion, required String operatingSystem, required String releaseDirectory})
const

Properties

artifactSize int
final
artifactType String
final
counter String
final
dartVersion String
final
environment String
final
flutterBuildNumber String
final
flutterVersion String
final
generatedFilename String
final
generatedTime String
final
hashCode int
The hash code for this object.
no setterinherited
operatingSystem String
final
projectName String
final
releaseDirectory String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited