ReleasePlugin class abstract
Abstract base class for defining extensibility points (Plugins).
Any future extensions to the flutter_build_manager should implement this interface and register themselves with the CLI.
Constructors
Properties
- description → String
-
A brief description of what the plugin does.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The unique name of the plugin.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
ArgResults results) → Future< void> -
Executes the core logic of the plugin using the parsed
results. -
initialize(
ReleaseManagerLogger logger) → Future< void> - Initialize the plugin with any necessary setup before execution.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerArguments(
ArgParser argParser) → void - Registers any custom command-line arguments needed by this plugin.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited