VersionModel class
Represents the version information extracted from a project.
Constructors
- VersionModel({required String projectName, required String version, required String buildNumber})
-
Creates a new VersionModel.
const
Properties
- buildNumber → String
-
The build number (e.g., '35').
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- projectName → String
-
The name of the project.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
The version string (e.g., '2.4.1').
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override