EnvironmentDetectionStrategy class abstract
Abstract base class for environment detection strategies.
Constructors
Properties
Methods
-
detect(
ArgResults? argResults) → Future< String?> - Attempts to detect the environment based on the strategy's rules.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited