detect abstract method

Future<String?> detect(
  1. ArgResults? argResults
)

Attempts to detect the environment based on the strategy's rules.

Receives the parsed argResults which may contain command-line flags. Returns the environment string if detected, otherwise returns null.

Implementation

Future<String?> detect(ArgResults? argResults);