ReleaseContext class
Holds the state of a release as it moves through the pipeline.
Constructors
- ReleaseContext({required String target, String? flavor, String? envFlag})
Properties
- buildResult ↔ BuildResultModel?
-
getter/setter pair
- envFlag → String?
-
final
- environment ↔ EnvironmentModel?
-
getter/setter pair
- finalArtifactPath ↔ String?
-
getter/setter pair
- finalChecksumPath ↔ String?
-
getter/setter pair
- finalMetadataPath ↔ String?
-
getter/setter pair
- finalReleaseDirectory ↔ String?
-
getter/setter pair
- flavor → String?
-
final
- generatedFilename ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextCounter ↔ String?
-
getter/setter pair
- project ↔ ProjectModel?
-
getter/setter pair
-
rollbackFiles
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → String
-
final
- version ↔ VersionModel?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited