ProcessService class
Defines the contract for OS process execution and provides
a concrete implementation using dart:io.
Constructors
-
ProcessService({required ReleaseManagerLogger logger, @visibleForTesting Future<
ProcessResult> processRunner(String executable, List<String> arguments, {bool runInShell, String? workingDirectory})?}) - Creates a ProcessService.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
String executable, List< String> arguments, {String? workingDirectory}) → Future<ProcessResult> -
Runs an executable with the given
executablename andarguments. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited