ReleaseDirectoryService class
Service responsible for constructing and creating the final release directory structure.
Constructors
- ReleaseDirectoryService({String configPath = 'flutter_build_manager.yaml'})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getReleaseDirectory(
{required String environment, String? basePath}) → Future< String> - Determines the release directory path based on configuration and current environment.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited